pub struct RequestContext<'a> { /* private fields */ }Expand description
processes all commands and keeps the application state
Implementations
Sourceimpl<'a> RequestContext<'a>
impl<'a> RequestContext<'a>
pub fn new(environment: &'a Environment) -> Self
pub fn environment(&self) -> &Environment
Sourcepub fn renderer(&self) -> Renderer<'_>
pub fn renderer(&self) -> Renderer<'_>
creates a new renderer based on the inner [’Environment`]
Sourcepub fn renderer_with_placeholders<'source>(
&'source self,
placeholders: &'source [Placeholder],
) -> Renderer<'source>
pub fn renderer_with_placeholders<'source>( &'source self, placeholders: &'source [Placeholder], ) -> Renderer<'source>
creates a new renderer based on the inner Environment
and the provided placeholders